/* jshint ignore:start */

/* jshint ignore:end */

define('books/adapters/application', ['exports', 'ember-data'], function (exports, DS) {

    'use strict';

    var ApplicationAdapter = DS['default'].RESTAdapter.extend({
        namespace: "api/v1"
    });

    exports['default'] = ApplicationAdapter;

});
define('books/app', ['exports', 'ember', 'ember/resolver', 'ember/load-initializers', 'books/config/environment'], function (exports, Ember, Resolver, loadInitializers, config) {

  'use strict';

  Ember['default'].MODEL_FACTORY_INJECTIONS = true;

  var App = Ember['default'].Application.extend({
    modulePrefix: config['default'].modulePrefix,
    podModulePrefix: config['default'].podModulePrefix,
    Resolver: Resolver['default']
  });

  loadInitializers['default'](App, config['default'].modulePrefix);

  exports['default'] = App;

});
define('books/components/star-rating', ['exports', 'ember'], function (exports, Ember) {

    'use strict';

    var StarRatingComponent = Ember['default'].Component.extend({
        maxStars: 0,
        starRating: 0,
        stars: [],
        tagName: "span",
        actions: {
            click: function click(star) {
                this.set("starRating", star.index);
                this.sendAction("action", star.index);
            }
        },
        setRating: (function () {
            var stars = [],
                i = 0;
            var starRating = this.get("starRating");
            for (i = 0; i < this.get("maxStars"); i++) {
                stars.pushObject(Ember['default'].Object.create({ empty: i >= starRating, index: i + 1 }));
            }
            this.set("stars", stars);
        }).observes("starRating").on("didInsertElement")
    });

    exports['default'] = StarRatingComponent;

});
define('books/controllers/index', ['exports', 'ember'], function (exports, Ember) {

  'use strict';

  var IndexController = Ember['default'].ArrayController.extend({

    // Query params are sort, order, filter, and filterValue
    // sync with the IndexRoute
    queryParams: ["sort", "order", "filter", "filterValue"],
    sort: null,
    order: null,
    filter: null,
    filterValue: null,

    actions: {

      // Toggle refinements from button.
      toggleRefinements: function toggleRefinements() {
        this.set("showRefinements", !this.get("showRefinements"));
      },

      // Refine the search based on the filters.
      refineSearchAction: function refineSearchAction() {
        this.refineSearch();
      }
    },

    // Sort by options exposed in the drop down.
    sortOptions: [{
      label: "Default",
      value: "id"
    }, {
      label: "Title",
      value: "title"
    }, {
      label: "Author",
      value: "author"
    }, {
      label: "Publication Year",
      value: "pubYear"
    }, {
      label: "Purchase Date",
      value: "purchaseDate"
    }, {
      label: "Rating",
      value: "rating"
    }, {
      label: "Read",
      value: "wasRead"
    }],

    // Ordering of the sort exposed in a drop down.
    orderOptions: [{
      label: "Ascending",
      value: "ASC"
    }, {
      label: "Descending",
      value: "DESC"
    }],

    // Filter by options exposed in the drop down.
    filterOptions: [{
      label: "None",
      value: ""
    }, {
      label: "Title",
      value: "title"
    }, {
      label: "Author",
      value: "author"
    }, {
      label: "Publication Year",
      value: "pubYear"
    }, {
      label: "Purchase Date",
      value: "purchaseDate"
    }, {
      label: "Rating",
      value: "rating"
    }, {
      label: "Read",
      value: "read"
    }, {
      label: "Unread",
      value: "unread"
    }],

    // Selected sort by option.
    selectedSortOption: null,

    // Selected order option.
    selectedOrderOption: null,

    // Selected filter by option.
    selectedFilterOption: null,

    // Selecte filter value.
    selectedFilterValue: null,

    // Show refinements or not
    showRefinements: false,

    // When true, refine button is disabled
    refineButtonDisabled: true,

    // If true, then show the filter value field
    showFilterValue: (function () {
      var filterOption = this.get("selectedFilterOption");
      if (filterOption) {
        if (filterOption.value !== this.get("filterOptions.0.value") && filterOption.value !== "read" && filterOption.value !== "unread") {
          return true;
        }
      }
      return false;
    }).property("selectedFilterOption"),

    // If true, then show the filter value field
    showOrder: (function () {
      var sortOption = this.get("selectedSortOption");
      return sortOption && sortOption.value !== this.get("sortOptions.0.value");
    }).property("selectedSortOption"),

    // Show when showRefinements is set to false, then clear the search params
    refinementVisibilityDidChange: (function () {
      if (!this.get("showRefinements")) {
        this.clearSearch();
      }
    }).observes("showRefinements"),

    sortAndFilterOptionsDidChange: (function () {
      var sortOption = this.get("selectedSortOption"),
          filterOption = this.get("selectedFilterOption");

      this.set("refineButtonDisabled", sortOption && sortOption.value === this.get("sortOptions.0.value") && (filterOption && filterOption.value === this.get("filterOptions.0.value")));
    }).observes("selectedSortOption", "selectedFilterOption"),

    // Refine the search based on the selected filters
    refineSearch: function refineSearch() {
      var selectedSortOption = this.get("selectedSortOption.value"),
          selectedOrderOption = this.get("selectedOrderOption.value"),
          selectedFilterOption = this.get("selectedFilterOption.value"),
          selectedFilterValue = this.get("selectedFilterValue");

      if (selectedSortOption !== this.get("sortOptions.0.value")) {
        this.set("sort", selectedSortOption).set("order", selectedOrderOption ? selectedOrderOption : this.get("orderOptions.0.value"));
      } else {
        this.set("sort", null).set("order", null);
      }

      if (selectedFilterOption !== this.get("filterOptions.0.value")) {

        if (selectedFilterOption === "unread" || selectedFilterOption === "read") {
          this.set("filter", "wasRead").set("filterValue", selectedFilterOption === "unread" ? false : true);
        } else {
          this.set("filter", selectedFilterOption);

          if (selectedFilterValue !== null) {
            this.set("filterValue", selectedFilterValue);
          }
        }
      } else {
        this.set("filter", null).set("filterValue", null);
      }
    },

    // Null out all filters
    clearSearch: function clearSearch() {
      this.set("sort", null).set("order", null).set("filter", null).set("filterValue", null).set("selectedSortOption", this.get("sortOptions.0")).set("selectedFilterOption", this.get("filterOptions.0")).set("selectedFilterValue", null);
    },

    // Make sure that the values are initialized correctly when entering
    // the route.
    syncFiltersOnInit: function syncFiltersOnInit() {
      var hasValidFilters = false,
          sortOptions = this.get("sortOptions"),
          orderOptions = this.get("orderOptions"),
          filterOptions = this.get("filterOptions"),
          sort = this.get("sort"),
          order = this.get("order"),
          filter = this.get("filter"),
          filterValue = this.get("filterValue"),
          self = this;

      sortOptions.forEach(function (option) {
        if (option && option.value === sort) {
          hasValidFilters = true;
          self.set("selectedSortOption", option);
        }
      });

      orderOptions.forEach(function (option) {
        if (option && option.value === order) {
          hasValidFilters = true;
          self.set("selectedOrderOption", option);
        }
      });

      if (filter === "wasRead") {
        if (filterValue === "true") {
          this.set("selectedFilterOption", filterOptions[6]);
        } else {
          this.set("selectedFilterOption", filterOptions[7]);
        }
        hasValidFilters = true;
      } else {
        filterOptions.forEach(function (option) {
          if (option && option.value === filter) {
            hasValidFilters = true;
            self.set("selectedFilterOption", option);
          }
        });
        if (filterValue !== null) {
          this.set("selectedFilterValue", filterValue);
        }
      }

      if (!hasValidFilters) {
        this.set("selectedSortOption", sortOptions[0]).set("selectedOrderOption", orderOptions[0]).set("selectedFilterOption", filterOptions[0]).set("selectedFilterValue", null);
      } else {
        this.set("showRefinements", true);
      }
    },

    init: function init() {
      this._super();

      // Run this in the next run loop to make sure that everything has been
      // propagated to the controller.
      Ember['default'].run.once(this, "syncFiltersOnInit");
    }

  });

  exports['default'] = IndexController;

});
define('books/initializers/app-version', ['exports', 'books/config/environment', 'ember'], function (exports, config, Ember) {

  'use strict';

  var classify = Ember['default'].String.classify;

  exports['default'] = {
    name: "App Version",
    initialize: function initialize(container, application) {
      var appName = classify(application.toString());
      Ember['default'].libraries.register(appName, config['default'].APP.version);
    }
  };

});
define('books/initializers/export-application-global', ['exports', 'ember', 'books/config/environment'], function (exports, Ember, config) {

  'use strict';

  exports.initialize = initialize;

  function initialize(container, application) {
    var classifiedName = Ember['default'].String.classify(config['default'].modulePrefix);

    if (config['default'].exportApplicationGlobal && !window[classifiedName]) {
      window[classifiedName] = application;
    }
  };

  exports['default'] = {
    name: "export-application-global",

    initialize: initialize
  };

});
define('books/models/book', ['exports', 'ember-data'], function (exports, DS) {

  'use strict';

  var Book = DS['default'].Model.extend({
    title: DS['default'].attr("string"),
    author: DS['default'].attr("string"),
    pubYear: DS['default'].attr("string", {
      defaultValue: function defaultValue() {
        return new Date().getFullYear();
      }
    }),
    purchaseDate: DS['default'].attr("string", {
      defaultValue: function defaultValue() {
        return new Date().toISOString().substring(0, 10);
      }
    }),
    note: DS['default'].attr("string"),
    rating: DS['default'].attr("number"),
    isbn: DS['default'].attr("string"),
    wasRead: DS['default'].attr("boolean", {
      defaultValue: function defaultValue() {
        return false;
      }
    }),

    purchaseDateHumanReadable: (function () {
      var purchaseDateComponents = (this.get("purchaseDate") || "").split("-");
      if (purchaseDateComponents.length === 3) {
        return "%@/%@/%@".fmt(purchaseDateComponents[1], purchaseDateComponents[2], purchaseDateComponents[0]);
      }
      return null;
    }).property("purchaseDate"),

    wasReadBool: (function (key, value) {
      if (value !== undefined) {
        this.set("wasRead", value);
      }
      if (this.get("wasRead") === "true" || this.get("wasRead") === true) {
        return true;
      }
      return false;
    }).property("wasRead")

  });

  exports['default'] = Book;

});
define('books/router', ['exports', 'ember', 'books/config/environment'], function (exports, Ember, config) {

  'use strict';

  var Router = Ember['default'].Router.extend({
    location: config['default'].locationType
  });

  Router.map(function () {
    this.resource("book", { path: "/book/:book_id" }, function () {
      this.route("edit");
    });

    this.route("new", { path: "/book/new" });
  });

  exports['default'] = Router;

});
define('books/routes/book', ['exports', 'ember'], function (exports, Ember) {

  'use strict';

  var BookRoute = Ember['default'].Route.extend({

    actions: {
      "delete": function (id) {
        // Make sure that you really want to delete it before doing it.
        var shouldDelete = confirm("Are you sure you want to delete this book?");
        if (shouldDelete) {
          this.store.find("book", id).then(function (book) {
            book.destroyRecord();
          });
          this.transitionTo("index");
        }
      }
    },

    model: function model(params) {
      return this.store.find("book", params.book_id);
    },

    setupController: function setupController(controller, model) {
      controller.set("content", model).set("isNotEditing", true).set("isNotNew", true);
    }
  });

  exports['default'] = BookRoute;

});
define('books/routes/book/edit', ['exports', 'ember'], function (exports, Ember) {

  'use strict';

  var BookEditRoute = Ember['default'].Route.extend({

    actions: {
      "delete": function (id) {
        // Make sure that you really want to delete it before doing it.
        var shouldDelete = confirm("Are you sure you want to delete this book?");
        if (shouldDelete) {
          this.store.find("book", id).then(function (book) {
            book.destroyRecord();
          });
          this.transitionTo("index");
        }
      },

      save: function save(id) {
        var self = this;
        this.store.find("book", id).then(function (book) {
          if (!book.get("isEmpty")) {
            book.save().then(function () {
              self.controller.set("isNotEditing", true);
              self.transitionTo("book.index", book.id);
            });
          }
        });
      },

      willTransition: function willTransition(transition) {
        if (this.controller.get("content").get("isDirty") && !confirm("Are you sure you want to abandon your edits?")) {
          transition.abort();
        } else if (this.controller.get("content").get("isEmpty")) {
          alert("You cannot have an empty book. Please fill it at least a title.");
          transition.abort();
        } else {
          return true;
        }
      }
    },

    setupController: function setupController(controller, model) {
      controller.set("content", model).set("isNotEditing", false).set("isNotNew", true);
    }

  });

  exports['default'] = BookEditRoute;

});
define('books/routes/index', ['exports', 'ember'], function (exports, Ember) {

  'use strict';

  var IndexRoute = Ember['default'].Route.extend({

    // Query params are sort, order, filter, and filterValue
    // sync with the IndexController
    queryParams: {
      sort: {
        refreshModel: true
      },
      order: {
        refreshModel: true
      },
      filter: {
        refreshModel: true
      },
      filterValue: {
        refreshModel: true
      }
    },

    model: function model(params) {
      return this.store.find("book", params);
    }
  });

  exports['default'] = IndexRoute;

});
define('books/routes/new', ['exports', 'ember'], function (exports, Ember) {

  'use strict';

  var NewRoute = Ember['default'].Route.extend({

    actions: {

      save: function save(book) {
        var self = this;

        if (!book.get("isEmpty")) {
          book.save().then(function (book) {
            self.transitionTo("book", book.id);
          });
        } else {
          alert("You cannot have an empty book. Please fill it at least a title.");
        }
      },

      willTransition: function willTransition(transition) {
        if (this.controller.get("content").get("isDirty") && !confirm("Are you sure you want discard your new book?")) {
          transition.abort();
        } else {
          return true;
        }
      }
    },

    model: function model() {
      return this.store.createRecord("book", {});
    },

    setupController: function setupController(controller, model) {
      controller.set("content", model).set("isNotEditing", false).set("isNotNew", false);
    },

    renderTemplate: function renderTemplate(controller, model) {
      this.render("book", {
        controller: controller,
        model: model
      });
    }
  });

  exports['default'] = NewRoute;

});
define('books/templates/application', ['exports'], function (exports) {

  'use strict';

  exports['default'] = Ember.HTMLBars.template((function() {
    return {
      isHTMLBars: true,
      blockParams: 0,
      cachedFragment: null,
      hasRendered: false,
      build: function build(dom) {
        var el0 = dom.createDocumentFragment();
        var el1 = dom.createTextNode("");
        dom.appendChild(el0, el1);
        var el1 = dom.createTextNode("\n");
        dom.appendChild(el0, el1);
        return el0;
      },
      render: function render(context, env, contextualElement) {
        var dom = env.dom;
        var hooks = env.hooks, content = hooks.content;
        dom.detectNamespace(contextualElement);
        var fragment;
        if (env.useFragmentCache && dom.canClone) {
          if (this.cachedFragment === null) {
            fragment = this.build(dom);
            if (this.hasRendered) {
              this.cachedFragment = fragment;
            } else {
              this.hasRendered = true;
            }
          }
          if (this.cachedFragment) {
            fragment = dom.cloneNode(this.cachedFragment, true);
          }
        } else {
          fragment = this.build(dom);
        }
        if (this.cachedFragment) { dom.repairClonedNode(fragment,[0]); }
        var morph0 = dom.createMorphAt(fragment,0,1,contextualElement);
        content(env, morph0, context, "outlet");
        return fragment;
      }
    };
  }()));

});
define('books/templates/book', ['exports'], function (exports) {

  'use strict';

  exports['default'] = Ember.HTMLBars.template((function() {
    var child0 = (function() {
      return {
        isHTMLBars: true,
        blockParams: 0,
        cachedFragment: null,
        hasRendered: false,
        build: function build(dom) {
          var el0 = dom.createTextNode("◀ Back");
          return el0;
        },
        render: function render(context, env, contextualElement) {
          var dom = env.dom;
          dom.detectNamespace(contextualElement);
          var fragment;
          if (env.useFragmentCache && dom.canClone) {
            if (this.cachedFragment === null) {
              fragment = this.build(dom);
              if (this.hasRendered) {
                this.cachedFragment = fragment;
              } else {
                this.hasRendered = true;
              }
            }
            if (this.cachedFragment) {
              fragment = dom.cloneNode(this.cachedFragment, true);
            }
          } else {
            fragment = this.build(dom);
          }
          return fragment;
        }
      };
    }());
    var child1 = (function() {
      var child0 = (function() {
        return {
          isHTMLBars: true,
          blockParams: 0,
          cachedFragment: null,
          hasRendered: false,
          build: function build(dom) {
            var el0 = dom.createTextNode("Edit");
            return el0;
          },
          render: function render(context, env, contextualElement) {
            var dom = env.dom;
            dom.detectNamespace(contextualElement);
            var fragment;
            if (env.useFragmentCache && dom.canClone) {
              if (this.cachedFragment === null) {
                fragment = this.build(dom);
                if (this.hasRendered) {
                  this.cachedFragment = fragment;
                } else {
                  this.hasRendered = true;
                }
              }
              if (this.cachedFragment) {
                fragment = dom.cloneNode(this.cachedFragment, true);
              }
            } else {
              fragment = this.build(dom);
            }
            return fragment;
          }
        };
      }());
      return {
        isHTMLBars: true,
        blockParams: 0,
        cachedFragment: null,
        hasRendered: false,
        build: function build(dom) {
          var el0 = dom.createDocumentFragment();
          var el1 = dom.createTextNode("      ");
          dom.appendChild(el0, el1);
          var el1 = dom.createTextNode("\n");
          dom.appendChild(el0, el1);
          return el0;
        },
        render: function render(context, env, contextualElement) {
          var dom = env.dom;
          var hooks = env.hooks, get = hooks.get, block = hooks.block;
          dom.detectNamespace(contextualElement);
          var fragment;
          if (env.useFragmentCache && dom.canClone) {
            if (this.cachedFragment === null) {
              fragment = this.build(dom);
              if (this.hasRendered) {
                this.cachedFragment = fragment;
              } else {
                this.hasRendered = true;
              }
            }
            if (this.cachedFragment) {
              fragment = dom.cloneNode(this.cachedFragment, true);
            }
          } else {
            fragment = this.build(dom);
          }
          var morph0 = dom.createMorphAt(fragment,0,1,contextualElement);
          block(env, morph0, context, "link-to", ["book.edit", get(env, context, "id")], {}, child0, null);
          return fragment;
        }
      };
    }());
    var child2 = (function() {
      return {
        isHTMLBars: true,
        blockParams: 0,
        cachedFragment: null,
        hasRendered: false,
        build: function build(dom) {
          var el0 = dom.createDocumentFragment();
          var el1 = dom.createTextNode("      ");
          dom.appendChild(el0, el1);
          var el1 = dom.createElement("a");
          var el2 = dom.createTextNode("Save");
          dom.appendChild(el1, el2);
          dom.appendChild(el0, el1);
          var el1 = dom.createTextNode("\n");
          dom.appendChild(el0, el1);
          return el0;
        },
        render: function render(context, env, contextualElement) {
          var dom = env.dom;
          var hooks = env.hooks, get = hooks.get, element = hooks.element;
          dom.detectNamespace(contextualElement);
          var fragment;
          if (env.useFragmentCache && dom.canClone) {
            if (this.cachedFragment === null) {
              fragment = this.build(dom);
              if (this.hasRendered) {
                this.cachedFragment = fragment;
              } else {
                this.hasRendered = true;
              }
            }
            if (this.cachedFragment) {
              fragment = dom.cloneNode(this.cachedFragment, true);
            }
          } else {
            fragment = this.build(dom);
          }
          var element1 = dom.childAt(fragment, [1]);
          element(env, element1, context, "action", ["save", get(env, context, "id")], {});
          return fragment;
        }
      };
    }());
    var child3 = (function() {
      return {
        isHTMLBars: true,
        blockParams: 0,
        cachedFragment: null,
        hasRendered: false,
        build: function build(dom) {
          var el0 = dom.createDocumentFragment();
          var el1 = dom.createTextNode("      ");
          dom.appendChild(el0, el1);
          var el1 = dom.createElement("a");
          dom.setAttribute(el1,"class","delete");
          var el2 = dom.createTextNode("Delete");
          dom.appendChild(el1, el2);
          dom.appendChild(el0, el1);
          var el1 = dom.createTextNode("\n");
          dom.appendChild(el0, el1);
          return el0;
        },
        render: function render(context, env, contextualElement) {
          var dom = env.dom;
          var hooks = env.hooks, get = hooks.get, element = hooks.element;
          dom.detectNamespace(contextualElement);
          var fragment;
          if (env.useFragmentCache && dom.canClone) {
            if (this.cachedFragment === null) {
              fragment = this.build(dom);
              if (this.hasRendered) {
                this.cachedFragment = fragment;
              } else {
                this.hasRendered = true;
              }
            }
            if (this.cachedFragment) {
              fragment = dom.cloneNode(this.cachedFragment, true);
            }
          } else {
            fragment = this.build(dom);
          }
          var element0 = dom.childAt(fragment, [1]);
          element(env, element0, context, "action", ["delete", get(env, context, "id")], {});
          return fragment;
        }
      };
    }());
    return {
      isHTMLBars: true,
      blockParams: 0,
      cachedFragment: null,
      hasRendered: false,
      build: function build(dom) {
        var el0 = dom.createElement("div");
        dom.setAttribute(el0,"id","detail");
        var el1 = dom.createTextNode("\n  ");
        dom.appendChild(el0, el1);
        var el1 = dom.createElement("header");
        var el2 = dom.createTextNode("\n    ");
        dom.appendChild(el1, el2);
        var el2 = dom.createElement("h1");
        dom.setAttribute(el2,"id","detail-title");
        var el3 = dom.createTextNode("Book Details");
        dom.appendChild(el2, el3);
        dom.appendChild(el1, el2);
        var el2 = dom.createTextNode("\n    ");
        dom.appendChild(el1, el2);
        var el2 = dom.createTextNode("\n");
        dom.appendChild(el1, el2);
        var el2 = dom.createTextNode("    \n");
        dom.appendChild(el1, el2);
        var el2 = dom.createTextNode("  ");
        dom.appendChild(el1, el2);
        dom.appendChild(el0, el1);
        var el1 = dom.createTextNode("\n  ");
        dom.appendChild(el0, el1);
        var el1 = dom.createElement("ul");
        var el2 = dom.createTextNode("\n    ");
        dom.appendChild(el1, el2);
        var el2 = dom.createElement("li");
        dom.setAttribute(el2,"class","title");
        var el3 = dom.createTextNode("\n      ");
        dom.appendChild(el2, el3);
        var el3 = dom.createElement("label");
        var el4 = dom.createTextNode("Title");
        dom.appendChild(el3, el4);
        dom.appendChild(el2, el3);
        var el3 = dom.createTextNode("\n      ");
        dom.appendChild(el2, el3);
        var el3 = dom.createTextNode("\n    ");
        dom.appendChild(el2, el3);
        dom.appendChild(el1, el2);
        var el2 = dom.createTextNode("\n    ");
        dom.appendChild(el1, el2);
        var el2 = dom.createElement("li");
        dom.setAttribute(el2,"class","author");
        var el3 = dom.createTextNode("\n      ");
        dom.appendChild(el2, el3);
        var el3 = dom.createElement("label");
        var el4 = dom.createTextNode("Author");
        dom.appendChild(el3, el4);
        dom.appendChild(el2, el3);
        var el3 = dom.createTextNode("\n      ");
        dom.appendChild(el2, el3);
        var el3 = dom.createTextNode("\n    ");
        dom.appendChild(el2, el3);
        dom.appendChild(el1, el2);
        var el2 = dom.createTextNode("\n    ");
        dom.appendChild(el1, el2);
        var el2 = dom.createElement("li");
        dom.setAttribute(el2,"class","pub-year");
        var el3 = dom.createTextNode("\n      ");
        dom.appendChild(el2, el3);
        var el3 = dom.createElement("label");
        var el4 = dom.createTextNode("Publication Year");
        dom.appendChild(el3, el4);
        dom.appendChild(el2, el3);
        var el3 = dom.createTextNode("\n      ");
        dom.appendChild(el2, el3);
        var el3 = dom.createTextNode("\n    ");
        dom.appendChild(el2, el3);
        dom.appendChild(el1, el2);
        var el2 = dom.createTextNode("\n    ");
        dom.appendChild(el1, el2);
        var el2 = dom.createElement("li");
        dom.setAttribute(el2,"class","purchase-date");
        var el3 = dom.createTextNode("\n      ");
        dom.appendChild(el2, el3);
        var el3 = dom.createElement("label");
        var el4 = dom.createTextNode("Purchase Date");
        dom.appendChild(el3, el4);
        dom.appendChild(el2, el3);
        var el3 = dom.createTextNode("\n      ");
        dom.appendChild(el2, el3);
        var el3 = dom.createTextNode("\n    ");
        dom.appendChild(el2, el3);
        dom.appendChild(el1, el2);
        var el2 = dom.createTextNode("\n    ");
        dom.appendChild(el1, el2);
        var el2 = dom.createElement("li");
        dom.setAttribute(el2,"class","rating");
        var el3 = dom.createTextNode("\n      ");
        dom.appendChild(el2, el3);
        var el3 = dom.createElement("label");
        var el4 = dom.createTextNode("Rating ");
        dom.appendChild(el3, el4);
        dom.appendChild(el2, el3);
        var el3 = dom.createTextNode("\n      ");
        dom.appendChild(el2, el3);
        var el3 = dom.createElement("p");
        var el4 = dom.createTextNode("\n        ");
        dom.appendChild(el3, el4);
        var el4 = dom.createTextNode("\n      ");
        dom.appendChild(el3, el4);
        dom.appendChild(el2, el3);
        var el3 = dom.createTextNode("\n    ");
        dom.appendChild(el2, el3);
        dom.appendChild(el1, el2);
        var el2 = dom.createTextNode("\n    ");
        dom.appendChild(el1, el2);
        var el2 = dom.createElement("li");
        dom.setAttribute(el2,"class","was-read");
        var el3 = dom.createTextNode("\n      ");
        dom.appendChild(el2, el3);
        var el3 = dom.createElement("label");
        var el4 = dom.createTextNode("Did you read it?");
        dom.appendChild(el3, el4);
        dom.appendChild(el2, el3);
        var el3 = dom.createTextNode("\n      ");
        dom.appendChild(el2, el3);
        var el3 = dom.createTextNode("\n    ");
        dom.appendChild(el2, el3);
        dom.appendChild(el1, el2);
        var el2 = dom.createTextNode("\n    ");
        dom.appendChild(el1, el2);
        var el2 = dom.createElement("li");
        dom.setAttribute(el2,"class","note");
        var el3 = dom.createTextNode("\n      ");
        dom.appendChild(el2, el3);
        var el3 = dom.createElement("label");
        var el4 = dom.createTextNode("Notes");
        dom.appendChild(el3, el4);
        dom.appendChild(el2, el3);
        var el3 = dom.createTextNode("\n      ");
        dom.appendChild(el2, el3);
        var el3 = dom.createTextNode("\n    ");
        dom.appendChild(el2, el3);
        dom.appendChild(el1, el2);
        var el2 = dom.createTextNode("\n  ");
        dom.appendChild(el1, el2);
        dom.appendChild(el0, el1);
        var el1 = dom.createTextNode("\n");
        dom.appendChild(el0, el1);
        return el0;
      },
      render: function render(context, env, contextualElement) {
        var dom = env.dom;
        var hooks = env.hooks, block = hooks.block, get = hooks.get, inline = hooks.inline;
        dom.detectNamespace(contextualElement);
        var fragment;
        if (env.useFragmentCache && dom.canClone) {
          if (this.cachedFragment === null) {
            fragment = this.build(dom);
            if (this.hasRendered) {
              this.cachedFragment = fragment;
            } else {
              this.hasRendered = true;
            }
          }
          if (this.cachedFragment) {
            fragment = dom.cloneNode(this.cachedFragment, true);
          }
        } else {
          fragment = this.build(dom);
        }
        var element2 = dom.childAt(fragment, [1]);
        var element3 = dom.childAt(fragment, [3]);
        var morph0 = dom.createMorphAt(element2,2,3);
        var morph1 = dom.createMorphAt(element2,3,4);
        var morph2 = dom.createMorphAt(element2,4,5);
        var morph3 = dom.createMorphAt(dom.childAt(element3, [1]),2,3);
        var morph4 = dom.createMorphAt(dom.childAt(element3, [3]),2,3);
        var morph5 = dom.createMorphAt(dom.childAt(element3, [5]),2,3);
        var morph6 = dom.createMorphAt(dom.childAt(element3, [7]),2,3);
        var morph7 = dom.createMorphAt(dom.childAt(element3, [9, 3]),0,1);
        var morph8 = dom.createMorphAt(dom.childAt(element3, [11]),2,3);
        var morph9 = dom.createMorphAt(dom.childAt(element3, [13]),2,3);
        block(env, morph0, context, "link-to", ["index"], {"class": "back"}, child0, null);
        block(env, morph1, context, "if", [get(env, context, "isNotEditing")], {}, child1, child2);
        block(env, morph2, context, "if", [get(env, context, "isNotNew")], {}, child3, null);
        inline(env, morph3, context, "input", [], {"type": "text", "value": get(env, context, "title"), "disabled": get(env, context, "isNotEditing")});
        inline(env, morph4, context, "input", [], {"type": "text", "value": get(env, context, "author"), "disabled": get(env, context, "isNotEditing")});
        inline(env, morph5, context, "input", [], {"type": "number", "value": get(env, context, "pubYear"), "max": "2014", "min": "0", "disabled": get(env, context, "isNotEditing")});
        inline(env, morph6, context, "input", [], {"type": "date", "value": get(env, context, "purchaseDate"), "disabled": get(env, context, "isNotEditing")});
        inline(env, morph7, context, "star-rating", [], {"starRating": get(env, context, "rating"), "maxStars": 5});
        inline(env, morph8, context, "input", [], {"type": "checkbox", "checked": get(env, context, "wasRead"), "disabled": get(env, context, "isNotEditing")});
        inline(env, morph9, context, "textarea", [], {"type": "checkbox", "value": get(env, context, "note"), "disabled": get(env, context, "isNotEditing")});
        return fragment;
      }
    };
  }()));

});
define('books/templates/components/star-rating', ['exports'], function (exports) {

  'use strict';

  exports['default'] = Ember.HTMLBars.template((function() {
    var child0 = (function() {
      var child0 = (function() {
        return {
          isHTMLBars: true,
          blockParams: 0,
          cachedFragment: null,
          hasRendered: false,
          build: function build(dom) {
            var el0 = dom.createDocumentFragment();
            var el1 = dom.createTextNode("      ");
            dom.appendChild(el0, el1);
            var el1 = dom.createElement("span");
            dom.setAttribute(el1,"style","color: #aaa;");
            var el2 = dom.createTextNode(" ☆");
            dom.appendChild(el1, el2);
            dom.appendChild(el0, el1);
            var el1 = dom.createTextNode("\n");
            dom.appendChild(el0, el1);
            return el0;
          },
          render: function render(context, env, contextualElement) {
            var dom = env.dom;
            dom.detectNamespace(contextualElement);
            var fragment;
            if (env.useFragmentCache && dom.canClone) {
              if (this.cachedFragment === null) {
                fragment = this.build(dom);
                if (this.hasRendered) {
                  this.cachedFragment = fragment;
                } else {
                  this.hasRendered = true;
                }
              }
              if (this.cachedFragment) {
                fragment = dom.cloneNode(this.cachedFragment, true);
              }
            } else {
              fragment = this.build(dom);
            }
            return fragment;
          }
        };
      }());
      var child1 = (function() {
        return {
          isHTMLBars: true,
          blockParams: 0,
          cachedFragment: null,
          hasRendered: false,
          build: function build(dom) {
            var el0 = dom.createDocumentFragment();
            var el1 = dom.createTextNode("        ");
            dom.appendChild(el0, el1);
            var el1 = dom.createElement("span");
            dom.setAttribute(el1,"style","color: #FFA500;");
            var el2 = dom.createTextNode(" ★");
            dom.appendChild(el1, el2);
            dom.appendChild(el0, el1);
            var el1 = dom.createTextNode("\n");
            dom.appendChild(el0, el1);
            return el0;
          },
          render: function render(context, env, contextualElement) {
            var dom = env.dom;
            dom.detectNamespace(contextualElement);
            var fragment;
            if (env.useFragmentCache && dom.canClone) {
              if (this.cachedFragment === null) {
                fragment = this.build(dom);
                if (this.hasRendered) {
                  this.cachedFragment = fragment;
                } else {
                  this.hasRendered = true;
                }
              }
              if (this.cachedFragment) {
                fragment = dom.cloneNode(this.cachedFragment, true);
              }
            } else {
              fragment = this.build(dom);
            }
            return fragment;
          }
        };
      }());
      return {
        isHTMLBars: true,
        blockParams: 0,
        cachedFragment: null,
        hasRendered: false,
        build: function build(dom) {
          var el0 = dom.createDocumentFragment();
          var el1 = dom.createTextNode("    ");
          dom.appendChild(el0, el1);
          var el1 = dom.createElement("span");
          var el2 = dom.createTextNode("\n");
          dom.appendChild(el1, el2);
          var el2 = dom.createTextNode("    ");
          dom.appendChild(el1, el2);
          dom.appendChild(el0, el1);
          var el1 = dom.createTextNode("\n");
          dom.appendChild(el0, el1);
          return el0;
        },
        render: function render(context, env, contextualElement) {
          var dom = env.dom;
          var hooks = env.hooks, get = hooks.get, element = hooks.element, block = hooks.block;
          dom.detectNamespace(contextualElement);
          var fragment;
          if (env.useFragmentCache && dom.canClone) {
            if (this.cachedFragment === null) {
              fragment = this.build(dom);
              if (this.hasRendered) {
                this.cachedFragment = fragment;
              } else {
                this.hasRendered = true;
              }
            }
            if (this.cachedFragment) {
              fragment = dom.cloneNode(this.cachedFragment, true);
            }
          } else {
            fragment = this.build(dom);
          }
          var element0 = dom.childAt(fragment, [1]);
          var morph0 = dom.createMorphAt(element0,0,1);
          element(env, element0, context, "action", ["click", get(env, context, "star")], {});
          block(env, morph0, context, "if", [get(env, context, "star.empty")], {}, child0, child1);
          return fragment;
        }
      };
    }());
    return {
      isHTMLBars: true,
      blockParams: 0,
      cachedFragment: null,
      hasRendered: false,
      build: function build(dom) {
        var el0 = dom.createDocumentFragment();
        var el1 = dom.createTextNode("");
        dom.appendChild(el0, el1);
        var el1 = dom.createTextNode("");
        dom.appendChild(el0, el1);
        return el0;
      },
      render: function render(context, env, contextualElement) {
        var dom = env.dom;
        var hooks = env.hooks, get = hooks.get, block = hooks.block;
        dom.detectNamespace(contextualElement);
        var fragment;
        if (env.useFragmentCache && dom.canClone) {
          if (this.cachedFragment === null) {
            fragment = this.build(dom);
            if (this.hasRendered) {
              this.cachedFragment = fragment;
            } else {
              this.hasRendered = true;
            }
          }
          if (this.cachedFragment) {
            fragment = dom.cloneNode(this.cachedFragment, true);
          }
        } else {
          fragment = this.build(dom);
        }
        if (this.cachedFragment) { dom.repairClonedNode(fragment,[0,1]); }
        var morph0 = dom.createMorphAt(fragment,0,1,contextualElement);
        block(env, morph0, context, "each", [get(env, context, "stars")], {"keyword": "star"}, child0, null);
        return fragment;
      }
    };
  }()));

});
define('books/templates/index', ['exports'], function (exports) {

  'use strict';

  exports['default'] = Ember.HTMLBars.template((function() {
    var child0 = (function() {
      return {
        isHTMLBars: true,
        blockParams: 0,
        cachedFragment: null,
        hasRendered: false,
        build: function build(dom) {
          var el0 = dom.createTextNode("        Clear\n");
          return el0;
        },
        render: function render(context, env, contextualElement) {
          var dom = env.dom;
          dom.detectNamespace(contextualElement);
          var fragment;
          if (env.useFragmentCache && dom.canClone) {
            if (this.cachedFragment === null) {
              fragment = this.build(dom);
              if (this.hasRendered) {
                this.cachedFragment = fragment;
              } else {
                this.hasRendered = true;
              }
            }
            if (this.cachedFragment) {
              fragment = dom.cloneNode(this.cachedFragment, true);
            }
          } else {
            fragment = this.build(dom);
          }
          return fragment;
        }
      };
    }());
    var child1 = (function() {
      return {
        isHTMLBars: true,
        blockParams: 0,
        cachedFragment: null,
        hasRendered: false,
        build: function build(dom) {
          var el0 = dom.createTextNode("        Refine\n");
          return el0;
        },
        render: function render(context, env, contextualElement) {
          var dom = env.dom;
          dom.detectNamespace(contextualElement);
          var fragment;
          if (env.useFragmentCache && dom.canClone) {
            if (this.cachedFragment === null) {
              fragment = this.build(dom);
              if (this.hasRendered) {
                this.cachedFragment = fragment;
              } else {
                this.hasRendered = true;
              }
            }
            if (this.cachedFragment) {
              fragment = dom.cloneNode(this.cachedFragment, true);
            }
          } else {
            fragment = this.build(dom);
          }
          return fragment;
        }
      };
    }());
    var child2 = (function() {
      return {
        isHTMLBars: true,
        blockParams: 0,
        cachedFragment: null,
        hasRendered: false,
        build: function build(dom) {
          var el0 = dom.createTextNode("+ New");
          return el0;
        },
        render: function render(context, env, contextualElement) {
          var dom = env.dom;
          dom.detectNamespace(contextualElement);
          var fragment;
          if (env.useFragmentCache && dom.canClone) {
            if (this.cachedFragment === null) {
              fragment = this.build(dom);
              if (this.hasRendered) {
                this.cachedFragment = fragment;
              } else {
                this.hasRendered = true;
              }
            }
            if (this.cachedFragment) {
              fragment = dom.cloneNode(this.cachedFragment, true);
            }
          } else {
            fragment = this.build(dom);
          }
          return fragment;
        }
      };
    }());
    var child3 = (function() {
      var child0 = (function() {
        return {
          isHTMLBars: true,
          blockParams: 0,
          cachedFragment: null,
          hasRendered: false,
          build: function build(dom) {
            var el0 = dom.createDocumentFragment();
            var el1 = dom.createTextNode("         ");
            dom.appendChild(el0, el1);
            var el1 = dom.createElement("label");
            var el2 = dom.createTextNode("Order By:");
            dom.appendChild(el1, el2);
            dom.appendChild(el0, el1);
            var el1 = dom.createTextNode(" \n         ");
            dom.appendChild(el0, el1);
            var el1 = dom.createTextNode("\n");
            dom.appendChild(el0, el1);
            return el0;
          },
          render: function render(context, env, contextualElement) {
            var dom = env.dom;
            var hooks = env.hooks, get = hooks.get, inline = hooks.inline;
            dom.detectNamespace(contextualElement);
            var fragment;
            if (env.useFragmentCache && dom.canClone) {
              if (this.cachedFragment === null) {
                fragment = this.build(dom);
                if (this.hasRendered) {
                  this.cachedFragment = fragment;
                } else {
                  this.hasRendered = true;
                }
              }
              if (this.cachedFragment) {
                fragment = dom.cloneNode(this.cachedFragment, true);
              }
            } else {
              fragment = this.build(dom);
            }
            var morph0 = dom.createMorphAt(fragment,2,3,contextualElement);
            inline(env, morph0, context, "view", [get(env, context, "Ember.Select")], {"content": get(env, context, "orderOptions"), "optionValuePath": "content.value", "optionLabelPath": "content.label", "selection": get(env, context, "selectedOrderOption")});
            return fragment;
          }
        };
      }());
      var child1 = (function() {
        return {
          isHTMLBars: true,
          blockParams: 0,
          cachedFragment: null,
          hasRendered: false,
          build: function build(dom) {
            var el0 = dom.createDocumentFragment();
            var el1 = dom.createTextNode("        ");
            dom.appendChild(el0, el1);
            var el1 = dom.createTextNode("\n");
            dom.appendChild(el0, el1);
            return el0;
          },
          render: function render(context, env, contextualElement) {
            var dom = env.dom;
            var hooks = env.hooks, get = hooks.get, inline = hooks.inline;
            dom.detectNamespace(contextualElement);
            var fragment;
            if (env.useFragmentCache && dom.canClone) {
              if (this.cachedFragment === null) {
                fragment = this.build(dom);
                if (this.hasRendered) {
                  this.cachedFragment = fragment;
                } else {
                  this.hasRendered = true;
                }
              }
              if (this.cachedFragment) {
                fragment = dom.cloneNode(this.cachedFragment, true);
              }
            } else {
              fragment = this.build(dom);
            }
            var morph0 = dom.createMorphAt(fragment,0,1,contextualElement);
            inline(env, morph0, context, "input", [], {"type": "text", "value": get(env, context, "selectedFilterValue"), "placeholder": "Value"});
            return fragment;
          }
        };
      }());
      return {
        isHTMLBars: true,
        blockParams: 0,
        cachedFragment: null,
        hasRendered: false,
        build: function build(dom) {
          var el0 = dom.createDocumentFragment();
          var el1 = dom.createTextNode("    ");
          dom.appendChild(el0, el1);
          var el1 = dom.createElement("div");
          dom.setAttribute(el1,"class","refine");
          var el2 = dom.createTextNode("\n      ");
          dom.appendChild(el1, el2);
          var el2 = dom.createElement("label");
          var el3 = dom.createTextNode("Sort By:");
          dom.appendChild(el2, el3);
          dom.appendChild(el1, el2);
          var el2 = dom.createTextNode(" \n      ");
          dom.appendChild(el1, el2);
          var el2 = dom.createTextNode("\n");
          dom.appendChild(el1, el2);
          var el2 = dom.createTextNode("      ");
          dom.appendChild(el1, el2);
          var el2 = dom.createElement("button");
          var el3 = dom.createTextNode("Refine");
          dom.appendChild(el2, el3);
          dom.appendChild(el1, el2);
          var el2 = dom.createTextNode("\n      ");
          dom.appendChild(el1, el2);
          var el2 = dom.createElement("br");
          dom.appendChild(el1, el2);
          var el2 = dom.createTextNode("\n      ");
          dom.appendChild(el1, el2);
          var el2 = dom.createElement("label");
          dom.setAttribute(el2,"class","row-two");
          var el3 = dom.createTextNode("Filter By:");
          dom.appendChild(el2, el3);
          dom.appendChild(el1, el2);
          var el2 = dom.createTextNode(" \n      ");
          dom.appendChild(el1, el2);
          var el2 = dom.createTextNode("\n");
          dom.appendChild(el1, el2);
          var el2 = dom.createTextNode("    ");
          dom.appendChild(el1, el2);
          dom.appendChild(el0, el1);
          var el1 = dom.createTextNode("\n");
          dom.appendChild(el0, el1);
          return el0;
        },
        render: function render(context, env, contextualElement) {
          var dom = env.dom;
          var hooks = env.hooks, get = hooks.get, inline = hooks.inline, block = hooks.block, element = hooks.element;
          dom.detectNamespace(contextualElement);
          var fragment;
          if (env.useFragmentCache && dom.canClone) {
            if (this.cachedFragment === null) {
              fragment = this.build(dom);
              if (this.hasRendered) {
                this.cachedFragment = fragment;
              } else {
                this.hasRendered = true;
              }
            }
            if (this.cachedFragment) {
              fragment = dom.cloneNode(this.cachedFragment, true);
            }
          } else {
            fragment = this.build(dom);
          }
          var element2 = dom.childAt(fragment, [1]);
          var element3 = dom.childAt(element2, [5]);
          var morph0 = dom.createMorphAt(element2,2,3);
          var morph1 = dom.createMorphAt(element2,3,4);
          var morph2 = dom.createMorphAt(element2,10,11);
          var morph3 = dom.createMorphAt(element2,11,12);
          inline(env, morph0, context, "view", [get(env, context, "Ember.Select")], {"content": get(env, context, "sortOptions"), "optionValuePath": "content.value", "optionLabelPath": "content.label", "selection": get(env, context, "selectedSortOption")});
          block(env, morph1, context, "if", [get(env, context, "showOrder")], {}, child0, null);
          element(env, element3, context, "action", ["refineSearchAction"], {});
          element(env, element3, context, "bind-attr", [], {"disabled": get(env, context, "refineButtonDisabled")});
          inline(env, morph2, context, "view", [get(env, context, "Ember.Select")], {"content": get(env, context, "filterOptions"), "optionValuePath": "content.value", "optionLabelPath": "content.label", "selection": get(env, context, "selectedFilterOption"), "class": "row-two"});
          block(env, morph3, context, "if", [get(env, context, "showFilterValue")], {}, child1, null);
          return fragment;
        }
      };
    }());
    var child4 = (function() {
      var child0 = (function() {
        var child0 = (function() {
          return {
            isHTMLBars: true,
            blockParams: 0,
            cachedFragment: null,
            hasRendered: false,
            build: function build(dom) {
              var el0 = dom.createDocumentFragment();
              var el1 = dom.createTextNode("          - ");
              dom.appendChild(el0, el1);
              var el1 = dom.createTextNode("\n");
              dom.appendChild(el0, el1);
              return el0;
            },
            render: function render(context, env, contextualElement) {
              var dom = env.dom;
              var hooks = env.hooks, content = hooks.content;
              dom.detectNamespace(contextualElement);
              var fragment;
              if (env.useFragmentCache && dom.canClone) {
                if (this.cachedFragment === null) {
                  fragment = this.build(dom);
                  if (this.hasRendered) {
                    this.cachedFragment = fragment;
                  } else {
                    this.hasRendered = true;
                  }
                }
                if (this.cachedFragment) {
                  fragment = dom.cloneNode(this.cachedFragment, true);
                }
              } else {
                fragment = this.build(dom);
              }
              var morph0 = dom.createMorphAt(fragment,0,1,contextualElement);
              content(env, morph0, context, "book.pubYear");
              return fragment;
            }
          };
        }());
        var child1 = (function() {
          return {
            isHTMLBars: true,
            blockParams: 0,
            cachedFragment: null,
            hasRendered: false,
            build: function build(dom) {
              var el0 = dom.createDocumentFragment();
              var el1 = dom.createTextNode("          ");
              dom.appendChild(el0, el1);
              var el1 = dom.createElement("span");
              dom.setAttribute(el1,"class","read");
              var el2 = dom.createTextNode("Read");
              dom.appendChild(el1, el2);
              dom.appendChild(el0, el1);
              var el1 = dom.createTextNode("\n");
              dom.appendChild(el0, el1);
              return el0;
            },
            render: function render(context, env, contextualElement) {
              var dom = env.dom;
              dom.detectNamespace(contextualElement);
              var fragment;
              if (env.useFragmentCache && dom.canClone) {
                if (this.cachedFragment === null) {
                  fragment = this.build(dom);
                  if (this.hasRendered) {
                    this.cachedFragment = fragment;
                  } else {
                    this.hasRendered = true;
                  }
                }
                if (this.cachedFragment) {
                  fragment = dom.cloneNode(this.cachedFragment, true);
                }
              } else {
                fragment = this.build(dom);
              }
              return fragment;
            }
          };
        }());
        var child2 = (function() {
          return {
            isHTMLBars: true,
            blockParams: 0,
            cachedFragment: null,
            hasRendered: false,
            build: function build(dom) {
              var el0 = dom.createDocumentFragment();
              var el1 = dom.createTextNode("          ");
              dom.appendChild(el0, el1);
              var el1 = dom.createElement("span");
              dom.setAttribute(el1,"class","unread");
              var el2 = dom.createTextNode("Unread");
              dom.appendChild(el1, el2);
              dom.appendChild(el0, el1);
              var el1 = dom.createTextNode("\n");
              dom.appendChild(el0, el1);
              return el0;
            },
            render: function render(context, env, contextualElement) {
              var dom = env.dom;
              dom.detectNamespace(contextualElement);
              var fragment;
              if (env.useFragmentCache && dom.canClone) {
                if (this.cachedFragment === null) {
                  fragment = this.build(dom);
                  if (this.hasRendered) {
                    this.cachedFragment = fragment;
                  } else {
                    this.hasRendered = true;
                  }
                }
                if (this.cachedFragment) {
                  fragment = dom.cloneNode(this.cachedFragment, true);
                }
              } else {
                fragment = this.build(dom);
              }
              return fragment;
            }
          };
        }());
        return {
          isHTMLBars: true,
          blockParams: 0,
          cachedFragment: null,
          hasRendered: false,
          build: function build(dom) {
            var el0 = dom.createDocumentFragment();
            var el1 = dom.createTextNode("    ");
            dom.appendChild(el0, el1);
            var el1 = dom.createElement("li");
            var el2 = dom.createTextNode("\n      ");
            dom.appendChild(el1, el2);
            var el2 = dom.createElement("p");
            var el3 = dom.createTextNode("\n        ");
            dom.appendChild(el2, el3);
            var el3 = dom.createTextNode("\n");
            dom.appendChild(el2, el3);
            var el3 = dom.createTextNode("        ");
            dom.appendChild(el2, el3);
            var el3 = dom.createElement("br");
            dom.appendChild(el2, el3);
            var el3 = dom.createTextNode("\n        ");
            dom.appendChild(el2, el3);
            var el3 = dom.createElement("span");
            dom.appendChild(el2, el3);
            var el3 = dom.createTextNode("\n        ");
            dom.appendChild(el2, el3);
            var el3 = dom.createTextNode("\n      ");
            dom.appendChild(el2, el3);
            dom.appendChild(el1, el2);
            var el2 = dom.createTextNode("\n      ");
            dom.appendChild(el1, el2);
            var el2 = dom.createElement("p");
            var el3 = dom.createTextNode("\n");
            dom.appendChild(el2, el3);
            var el3 = dom.createTextNode("      ");
            dom.appendChild(el2, el3);
            dom.appendChild(el1, el2);
            var el2 = dom.createTextNode("\n      ");
            dom.appendChild(el1, el2);
            dom.appendChild(el0, el1);
            var el1 = dom.createTextNode("\n");
            dom.appendChild(el0, el1);
            return el0;
          },
          render: function render(context, env, contextualElement) {
            var dom = env.dom;
            var hooks = env.hooks, content = hooks.content, get = hooks.get, block = hooks.block, inline = hooks.inline;
            dom.detectNamespace(contextualElement);
            var fragment;
            if (env.useFragmentCache && dom.canClone) {
              if (this.cachedFragment === null) {
                fragment = this.build(dom);
                if (this.hasRendered) {
                  this.cachedFragment = fragment;
                } else {
                  this.hasRendered = true;
                }
              }
              if (this.cachedFragment) {
                fragment = dom.cloneNode(this.cachedFragment, true);
              }
            } else {
              fragment = this.build(dom);
            }
            var element0 = dom.childAt(fragment, [1]);
            var element1 = dom.childAt(element0, [1]);
            var morph0 = dom.createMorphAt(element1,0,1);
            var morph1 = dom.createMorphAt(element1,1,2);
            var morph2 = dom.createMorphAt(dom.childAt(element1, [5]),-1,-1);
            var morph3 = dom.createMorphAt(element1,6,7);
            var morph4 = dom.createMorphAt(dom.childAt(element0, [3]),0,1);
            content(env, morph0, context, "book.title");
            block(env, morph1, context, "if", [get(env, context, "book.pubYear")], {}, child0, null);
            content(env, morph2, context, "book.author");
            inline(env, morph3, context, "star-rating", [], {"starRating": get(env, context, "book.rating"), "maxStars": 5});
            block(env, morph4, context, "if", [get(env, context, "book.wasReadBool")], {}, child1, child2);
            return fragment;
          }
        };
      }());
      return {
        isHTMLBars: true,
        blockParams: 0,
        cachedFragment: null,
        hasRendered: false,
        build: function build(dom) {
          var el0 = dom.createDocumentFragment();
          var el1 = dom.createTextNode("");
          dom.appendChild(el0, el1);
          var el1 = dom.createTextNode("");
          dom.appendChild(el0, el1);
          return el0;
        },
        render: function render(context, env, contextualElement) {
          var dom = env.dom;
          var hooks = env.hooks, get = hooks.get, block = hooks.block;
          dom.detectNamespace(contextualElement);
          var fragment;
          if (env.useFragmentCache && dom.canClone) {
            if (this.cachedFragment === null) {
              fragment = this.build(dom);
              if (this.hasRendered) {
                this.cachedFragment = fragment;
              } else {
                this.hasRendered = true;
              }
            }
            if (this.cachedFragment) {
              fragment = dom.cloneNode(this.cachedFragment, true);
            }
          } else {
            fragment = this.build(dom);
          }
          if (this.cachedFragment) { dom.repairClonedNode(fragment,[0,1]); }
          var morph0 = dom.createMorphAt(fragment,0,1,contextualElement);
          block(env, morph0, context, "link-to", ["book", get(env, context, "book.id")], {}, child0, null);
          return fragment;
        }
      };
    }());
    return {
      isHTMLBars: true,
      blockParams: 0,
      cachedFragment: null,
      hasRendered: false,
      build: function build(dom) {
        var el0 = dom.createElement("div");
        dom.setAttribute(el0,"id","book-list");
        var el1 = dom.createTextNode("\n  ");
        dom.appendChild(el0, el1);
        var el1 = dom.createElement("header");
        var el2 = dom.createTextNode("\n    ");
        dom.appendChild(el1, el2);
        var el2 = dom.createElement("h1");
        dom.setAttribute(el2,"id","books");
        var el3 = dom.createTextNode("My Books");
        dom.appendChild(el2, el3);
        dom.appendChild(el1, el2);
        var el2 = dom.createTextNode("\n    ");
        dom.appendChild(el1, el2);
        var el2 = dom.createElement("a");
        dom.setAttribute(el2,"class","show-refinement");
        var el3 = dom.createTextNode("\n");
        dom.appendChild(el2, el3);
        var el3 = dom.createTextNode("    ");
        dom.appendChild(el2, el3);
        dom.appendChild(el1, el2);
        var el2 = dom.createTextNode("\n    ");
        dom.appendChild(el1, el2);
        var el2 = dom.createTextNode("\n  ");
        dom.appendChild(el1, el2);
        dom.appendChild(el0, el1);
        var el1 = dom.createTextNode("\n");
        dom.appendChild(el0, el1);
        var el1 = dom.createTextNode("  ");
        dom.appendChild(el0, el1);
        var el1 = dom.createElement("ul");
        var el2 = dom.createTextNode("\n");
        dom.appendChild(el1, el2);
        var el2 = dom.createTextNode("\n  ");
        dom.appendChild(el1, el2);
        dom.appendChild(el0, el1);
        var el1 = dom.createTextNode("\n");
        dom.appendChild(el0, el1);
        return el0;
      },
      render: function render(context, env, contextualElement) {
        var dom = env.dom;
        var hooks = env.hooks, element = hooks.element, get = hooks.get, block = hooks.block;
        dom.detectNamespace(contextualElement);
        var fragment;
        if (env.useFragmentCache && dom.canClone) {
          if (this.cachedFragment === null) {
            fragment = this.build(dom);
            if (this.hasRendered) {
              this.cachedFragment = fragment;
            } else {
              this.hasRendered = true;
            }
          }
          if (this.cachedFragment) {
            fragment = dom.cloneNode(this.cachedFragment, true);
          }
        } else {
          fragment = this.build(dom);
        }
        var element4 = fragment;
        var element5 = dom.childAt(element4, [1]);
        var element6 = dom.childAt(element5, [3]);
        var morph0 = dom.createMorphAt(element6,0,1);
        var morph1 = dom.createMorphAt(element5,4,5);
        var morph2 = dom.createMorphAt(element4,2,3);
        var morph3 = dom.createMorphAt(dom.childAt(element4, [4]),0,1);
        element(env, element4, context, "bind-attr", [], {"class": "showRefinements"});
        element(env, element6, context, "action", ["toggleRefinements"], {});
        block(env, morph0, context, "if", [get(env, context, "showRefinements")], {}, child0, child1);
        block(env, morph1, context, "link-to", ["new"], {"class": "new"}, child2, null);
        block(env, morph2, context, "if", [get(env, context, "showRefinements")], {}, child3, null);
        block(env, morph3, context, "each", [get(env, context, "controller")], {"keyword": "book"}, child4, null);
        return fragment;
      }
    };
  }()));

});
define('books/tests/adapters/application.jshint', function () {

  'use strict';

  module('JSHint - adapters');
  test('adapters/application.js should pass jshint', function() { 
    ok(true, 'adapters/application.js should pass jshint.'); 
  });

});
define('books/tests/app.jshint', function () {

  'use strict';

  module('JSHint - .');
  test('app.js should pass jshint', function() { 
    ok(true, 'app.js should pass jshint.'); 
  });

});
define('books/tests/components/star-rating.jshint', function () {

  'use strict';

  module('JSHint - components');
  test('components/star-rating.js should pass jshint', function() { 
    ok(true, 'components/star-rating.js should pass jshint.'); 
  });

});
define('books/tests/controllers/index.jshint', function () {

  'use strict';

  module('JSHint - controllers');
  test('controllers/index.js should pass jshint', function() { 
    ok(true, 'controllers/index.js should pass jshint.'); 
  });

});
define('books/tests/helpers/resolver', ['exports', 'ember/resolver', 'books/config/environment'], function (exports, Resolver, config) {

  'use strict';

  var resolver = Resolver['default'].create();

  resolver.namespace = {
    modulePrefix: config['default'].modulePrefix,
    podModulePrefix: config['default'].podModulePrefix
  };

  exports['default'] = resolver;

});
define('books/tests/helpers/resolver.jshint', function () {

  'use strict';

  module('JSHint - helpers');
  test('helpers/resolver.js should pass jshint', function() { 
    ok(true, 'helpers/resolver.js should pass jshint.'); 
  });

});
define('books/tests/helpers/start-app', ['exports', 'ember', 'books/app', 'books/router', 'books/config/environment'], function (exports, Ember, Application, Router, config) {

  'use strict';



  exports['default'] = startApp;
  function startApp(attrs) {
    var application;

    var attributes = Ember['default'].merge({}, config['default'].APP);
    attributes = Ember['default'].merge(attributes, attrs); // use defaults, but you can override;

    Ember['default'].run(function () {
      application = Application['default'].create(attributes);
      application.setupForTesting();
      application.injectTestHelpers();
    });

    return application;
  }

});
define('books/tests/helpers/start-app.jshint', function () {

  'use strict';

  module('JSHint - helpers');
  test('helpers/start-app.js should pass jshint', function() { 
    ok(true, 'helpers/start-app.js should pass jshint.'); 
  });

});
define('books/tests/models/book.jshint', function () {

  'use strict';

  module('JSHint - models');
  test('models/book.js should pass jshint', function() { 
    ok(true, 'models/book.js should pass jshint.'); 
  });

});
define('books/tests/router.jshint', function () {

  'use strict';

  module('JSHint - .');
  test('router.js should pass jshint', function() { 
    ok(true, 'router.js should pass jshint.'); 
  });

});
define('books/tests/routes/book.jshint', function () {

  'use strict';

  module('JSHint - routes');
  test('routes/book.js should pass jshint', function() { 
    ok(true, 'routes/book.js should pass jshint.'); 
  });

});
define('books/tests/routes/book/edit.jshint', function () {

  'use strict';

  module('JSHint - routes/book');
  test('routes/book/edit.js should pass jshint', function() { 
    ok(true, 'routes/book/edit.js should pass jshint.'); 
  });

});
define('books/tests/routes/index.jshint', function () {

  'use strict';

  module('JSHint - routes');
  test('routes/index.js should pass jshint', function() { 
    ok(true, 'routes/index.js should pass jshint.'); 
  });

});
define('books/tests/routes/new.jshint', function () {

  'use strict';

  module('JSHint - routes');
  test('routes/new.js should pass jshint', function() { 
    ok(true, 'routes/new.js should pass jshint.'); 
  });

});
define('books/tests/test-helper', ['books/tests/helpers/resolver', 'ember-qunit'], function (resolver, ember_qunit) {

	'use strict';

	ember_qunit.setResolver(resolver['default']);

});
define('books/tests/test-helper.jshint', function () {

  'use strict';

  module('JSHint - .');
  test('test-helper.js should pass jshint', function() { 
    ok(true, 'test-helper.js should pass jshint.'); 
  });

});
/* jshint ignore:start */

/* jshint ignore:end */

/* jshint ignore:start */

define('books/config/environment', ['ember'], function(Ember) {
  var prefix = 'books';
/* jshint ignore:start */

try {
  var metaName = prefix + '/config/environment';
  var rawConfig = Ember['default'].$('meta[name="' + metaName + '"]').attr('content');
  var config = JSON.parse(unescape(rawConfig));

  return { 'default': config };
}
catch(err) {
  throw new Error('Could not read config from meta tag with name "' + metaName + '".');
}

/* jshint ignore:end */

});

if (runningTests) {
  require("books/tests/test-helper");
} else {
  require("books/app")["default"].create({"name":"books","version":"0.0.0.7eeec1bb"});
}

/* jshint ignore:end */
//# sourceMappingURL=books.map